@@ -1,7 +1,7 @@
 # Commands
 
 # License {{{1
-# Copyright (C) 2016-2020 Kenneth S. Kundert
+# Copyright (C) 2016-2022 Kenneth S. Kundert
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,11 +27,11 @@ from .generator import PasswordGenerator
 from .gpg import GnuPG, PythonFile
 from .obscure import ObscuredSecret
 from .shlib import chmod, cp, rm, to_path
-from .utilities import query_user, two_columns, OSErrors, name_completion
+from .utilities import query_user, two_columns, name_completion
 from .writer import get_writer
 from inform import (
-    codicil, columns, cull, display, error, full_stop, narrate, output, warn,
-    conjoin, join, os_error, is_collection, indent, render,
+    codicil, columns, conjoin, cull, display, error, Error, indent,
+    is_collection, join, narrate, os_error, output, render, title_case, warn,
 )
 from docopt import docopt
 from textwrap import dedent
@@ -41,7 +41,7 @@ import sys
 
 # Utilities {{{1
 def title(text):
-    return full_stop(text[0].upper() + text[1:])
+    return title_case(text)
 
 
 # Command base class {{{1
@@ -155,7 +155,7 @@ class Add(Command):
         as in '<<_ACCOUNT_NUMBER_>>', the value you enter will be concealed.
 
         You can create your own templates by adding them to 'account_templates'
-        in the ~/.config/avendesora/config file.
+        or 'additional_account_templates' in the ~/.config/avendesora/config file.
 
         You can change the editor used when adding account by changing the
         'edit_template', also found in the ~/.config/avendesora/config file.
@@ -179,11 +179,16 @@ class Add(Command):
             indent = get_setting('indent')
             return indent + ('\n' + indent).join(sorted(l))
 
+        templates = sorted(
+            list(get_setting('account_templates').keys()) +
+            list(get_setting('additional_account_templates').keys())
+        )
+
         return text.format(
-            title=title(cls.DESCRIPTION), usage=cls.USAGE,
-            default=get_setting('default_account_template'),
-            templates=indented_list(get_setting('account_templates').keys()),
-            files=indented_list(get_setting('accounts_files', [])),
+            title = title(cls.DESCRIPTION), usage=cls.USAGE,
+            default = get_setting('default_account_template'),
+            templates = indented_list(templates),
+            files = indented_list(get_setting('accounts_files', [])),
         )
 
     @classmethod
@@ -213,6 +218,7 @@ class Add(Command):
         try:
             # get the specified template
             templates = get_setting('account_templates')
+            templates.update(get_setting('additional_account_templates'))
             if cmdline['<template>']:
                 template_name = cmdline['<template>']
             else:
@@ -241,7 +247,7 @@ class Add(Command):
             tmpfilename = mktemp(suffix='_avendesora.gpg')
             tmpfile = GnuPG(tmpfilename)
             tmpfile.save(template, get_setting('gpg_ids'))
-        except OSErrors as e:
+        except OSError as e:
             raise PasswordError(os_error(e))
 
         # open template in the editor
@@ -289,13 +295,12 @@ class Add(Command):
                             'Giving up, restoring original file.'
                         )
 
-        except (PasswordError,) + OSErrors as e:
+        except (PasswordError, OSError) as e:
             orig_accounts_file.restore()
-            if isinstance(e, OSErrors):
+            if isinstance(e, OSError):
                 e = os_error(e)
             error(e)
             codicil(
-                '',
                 'What you entered can be found in %s.' % tmpfilename,
                 'Delete it when done with it.', sep='\n'
             )
@@ -304,7 +309,7 @@ class Add(Command):
         # delete the temp file
         try:
             tmpfile.remove()
-        except:
+        except Exception:
             pass
 
 
@@ -360,7 +365,7 @@ class Archive(Command):
             if previous_archive and archive_file.is_file():
                 rm(previous_archive)
                 cp(archive_file, previous_archive)
-        except OSErrors as e:
+        except OSError as e:
             raise PasswordError(os_error(e))
 
         # delete the manifests, causing them to be recreated clean
@@ -396,7 +401,7 @@ class Archive(Command):
         try:
             archive.save(contents)
             chmod(0o600, archive_file)
-        except OSErrors as e:
+        except OSError as e:
             raise PasswordError(os_error(e), culprit=archive_file)
 
 
@@ -563,7 +568,7 @@ class Changed(Command):
                     archive_value = archive_account[field_name]
                     current_value = current_account[field_name]
                     if is_collection(current_value) != is_collection(archive_value):
-                        output(account_name, 'field dimension differs', field_name, sep=': ')
+                        output(account_name, 'number of items in field differs', field_name, sep=': ')
                     elif is_collection(current_value):
                         archive_items = Collection(archive_account[field_name]).items()
                         current_items = Collection(current_account[field_name]).items()
@@ -709,7 +714,7 @@ class Edit(Command):
             accounts_file = PythonFile(account._file_info_.path)
             accounts_file.backup('.saved')
             account_name = account.__name__
-        except OSErrors as e:
+        except OSError as e:
             raise PasswordError(os_error(e))
 
         # allow the user to edit, and then check and make sure it is valid
@@ -733,7 +738,7 @@ class Edit(Command):
         except PasswordError:
             accounts_file.restore()
             raise
-        except OSErrors as e:
+        except OSError as e:
             accounts_file.restore()
             raise PasswordError(os_error(e))
 
@@ -764,9 +769,9 @@ class Find(Command):
             desc = getattr(acct, 'desc', None)
             to_print.append(
                 join(acct.get_name(), aliases=aliases, desc=desc, template=(
-                    '{} ({aliases:|, }) -- {desc}',
+                    '{} ({aliases:|, }) — {desc}',
                     '{} ({aliases:|, })',
-                    '{} -- {desc}',
+                    '{} — {desc}',
                     '{}'
                 ))
             )
@@ -1016,7 +1021,7 @@ class Interactive(Command):
                         get_setting('default_vector_field'),
                         int(choice)
                     )
-                except:
+                except Exception:
                     pass
                 try:
                     writer.display_field(account, choice)
@@ -1065,7 +1070,7 @@ class Log(Command):
             try:
                 rm(logfile)
                 return
-            except OSErrors as e:
+            except OSError as e:
                 raise PasswordError(os_error(e))
         if not logfile.exists():
             raise PasswordError('log file was not found.')
@@ -1238,7 +1243,7 @@ class PhoneticAlphabet(Command):
             Lima Mike November Oscar Papa Quebec Romeo Sierra Tango Uniform
             Victor Whiskey X-ray Yankee Zulu
         """.split()
-        mapping = {w[0].lower():w for w in words}
+        mapping = {w[0].lower(): w for w in words}
         mapping.update({
             '0':'Zero', '1':'One', '2':'Two', '3':'Three', '4':'Four',
             '5':'Five', '6':'Six', '7':'Seven', '8':'Eight', '9':'Nine'
@@ -1270,7 +1275,7 @@ class Questions(Command):
             avendesora questions [options] <account> [<field>]
 
         Options:
-            -c, --clipboard         Write output to clipboard rather than stdout.
+            -c, --clipboard         Write output to clipboard rather than to tty.
             -S, --seed              Interactively request additional seed for
                                     generated secrets.
 
@@ -1404,9 +1409,9 @@ class Search(Command):
             desc = getattr(acct, 'desc', None)
             to_print.append(
                 join(acct.get_name(), aliases=aliases, desc=desc, template=(
-                    '{} ({aliases:|, }) -- {desc}',
+                    '{} ({aliases:|, }) — {desc}',
                     '{} ({aliases:|, })',
-                    '{} -- {desc}',
+                    '{} — {desc}',
                     '{}'
                 ))
             )
@@ -1426,7 +1431,7 @@ class Value(Command):
             avendesora value [options] [<account> [<field>]]
 
         Options:
-            -c, --clipboard         Write output to clipboard rather than stdout.
+            -c, --clipboard         Write output to clipboard rather than to tty.
             -s, --stdout            Write output to the standard output without
                                     any annotation or protections.
             -S, --seed              Interactively request additional seed for
@@ -1441,6 +1446,11 @@ class Value(Command):
 
             avendesora value bank pin
 
+        If you don't specify the field, you get the value of the default field.
+        For first level fields, you only need to specify enough leading
+        characters of the field name to uniquely identify which field you wish.
+        If you specify ? as the field, the available fields will be listed.
+
         If the requested value is composite (an array or dictionary), you should
         also specify a key that indicates which of the composite values you
         want. For example, if the 'accounts' field is a dictionary, you specify
@@ -1523,6 +1533,7 @@ class Value(Command):
         # read command line
         cmdline = docopt(cls.USAGE, argv=[command] + args)
         use_clipboard = cmdline['--clipboard']
+        field = cmdline['<field>']
 
         # mute any warnings if using --stdout
         if cmdline['--stdout']:
@@ -1536,10 +1547,30 @@ class Value(Command):
         account_name = cmdline['<account>']
         if account_name:
             account = generator.get_account(account_name, cmdline['--seed'])
+
+            # simply list available fields if field is given as ?
+            if field == "?":
+                display("Available fields:")
+                for field in account.fields(sort=True):
+                    display(f"    {field}")
+                return
+
+            # given field may be just first few letters, find desired field
+            if field and field.isalnum():
+                candidates = [f for f in account.fields() if f.startswith(field)]
+                if candidates:
+                    field = candidates[0]
+                    if len(candidates) > 1:
+                        raise Error(
+                            f"matches multiple fields: {', '.join(candidates)}.",
+                            culprit = cmdline['<field>']
+                        )
+
+            # output desired value
             writer = get_writer(
                 clipboard=use_clipboard, stdout=cmdline['--stdout']
             )
-            writer.display_field(account, cmdline['<field>'])
+            writer.display_field(account, field)
         else:
             # use discovery to determine account
             script = generator.discover_account(
