@@ -1,7 +1,7 @@
 # Password Generator
 
 # License {{{1
-# Copyright (C) 2016-2020 Kenneth S. Kundert
+# Copyright (C) 2016-2022 Kenneth S. Kundert
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -21,7 +21,7 @@
 from .account import Account
 from .config import read_config, get_setting
 from .dialog import show_list_dialog
-from .dictionary import DICTIONARY
+from .dictionary import Dictionary
 from .error import PasswordError
 from .files import AccountFiles
 from .gpg import GnuPG, PythonFile, GPG_EXTENSIONS
@@ -36,7 +36,7 @@ from .script import Script
 from .secrets import Passphrase
 from .shlib import to_path, getmod, mv, rm
 from .title import Title
-from .utilities import generate_random_string, OSErrors
+from .utilities import generate_random_string
 from inform import codicil, conjoin, log, os_error, render, warn, is_str
 from textwrap import dedent, wrap
 from pathlib import Path
@@ -62,7 +62,12 @@ class PasswordGenerator(object):
             If true will validate that certain critical components in Avendesora
             have not be tampered with.  Checking the integrity can take up to a
             second, so recommend you pass False on interactive commands that
-            benefit from low startup overhead.
+            benefit from low startup overhead and True on the more expensive
+            commands to assure integrity is occasionally checked.
+
+        warnings (bool):
+            Suppress warnings from accounts. Useful when processing many
+            accounts.  Does not affect warnings from the integrity check.
 
     Raises:
         :exc:`avendesora.PasswordError`:
@@ -71,7 +76,7 @@ class PasswordGenerator(object):
 
     # Constructor {{{2
     def __init__(
-            self, init=False, gpg_ids=None, check_integrity=True, warnings=True
+            self, init=False, gpg_ids=None, check_integrity=False, warnings=True
     ):
         # initialize avendesora (these should already be done if called from
         # main, but it is safe to call them again)
@@ -134,7 +139,7 @@ class PasswordGenerator(object):
         if (get_setting('config_doc_file')):
             try:
                 rm(get_setting('config_doc_file'))
-            except OSErrors as e:
+            except OSError as e:
                 warn(os_error(e))
 
         # create the initial versions of the files in the settings directory
@@ -183,7 +188,7 @@ class PasswordGenerator(object):
             try:
                 mv(path, str(path) + '~')
                 f.create(ACCOUNT_LIST_FILE_CONTENTS.format(**fields), gpg_ids)
-            except OSErrors as e:
+            except OSError as e:
                 raise PasswordError(os_error(e))
 
     # _validate_components() (private) {{{2
@@ -208,15 +213,15 @@ class PasswordGenerator(object):
         for path, kind in [
             (to_path(resource_filename(__name__, 'secrets.py')), 'secrets_hash'),
             (to_path(resource_filename(__name__, 'charsets.py')), 'charsets_hash'),
-            (None, 'dict_hash'),
+            ('default', 'dict_hash'),
+            ('mnemonic', 'mnemonic_hash'),
         ]:
-            if path:
-                try:
-                    contents = path.read_text()
-                except OSErrors as e:
-                    raise PasswordError(os_error(e))
-            else:
-                contents = '\n'.join(DICTIONARY.get_words())
+            try:
+                contents = path.read_text()
+            except AttributeError:
+                contents = '\n'.join(Dictionary(path).get_words())
+            except OSError as e:
+                raise PasswordError(os_error(e))
             md5 = hashlib.md5(contents.encode('utf-8')).hexdigest()
             # Check that file has not changed.
             if md5 != get_setting(kind):
@@ -264,6 +269,42 @@ class PasswordGenerator(object):
         account.initialize(request_seed, stealth_name)
         return account
 
+    # get_value() {{{2
+    def get_value(self, path, request_seed=False, stealth_name=None):
+        """Get account value given path that includes account and field names.
+
+        Args:
+            path (str):
+                Path includes account name and field name separated by a colon.
+                Paths of the following forms are accepted:
+
+                    |  *account*: account's default field
+                    |  *account:name*: account and field name of a scalar value
+                    |  *account:name.key* or *account:name[key]*:
+                    |      member of a dictionary or array
+                    |      key is string for dictionary, integer for array
+
+            request_seed (str or bool):
+                If specified an additional seed is provided to the account (see:
+                :ref:`misdirection <misdirection>`).  It may be specified as a
+                string, in which case it is used as the seed.  Otherwise if
+                true, the seed it requested directly from the user.
+            stealth_name (str):
+                The name used as the account name if the account is a stealth
+                account.
+
+        Returns:
+            :class:`avendesora.Account`: An account. The class itself is
+            returned, and not an instance of the class.
+
+        Raises:
+            :exc:`avendesora.PasswordError`:
+                There is no account of field that matches the given path.
+        """
+        name, _, field = path.partition(':')
+        account = self.get_account(name.strip(), request_seed, stealth_name)
+        return account.get_value(field.strip())
+
     # discover_account() {{{2
     def discover_account(self, url=None, title=None, verbose=False):
         """Discover the account from the environment.
