@@ -2,7 +2,7 @@
 # API for an account
 
 # License {{{1
-# Copyright (C) 2016-2020 Kenneth S. Kundert
+# Copyright (C) 2016-2022 Kenneth S. Kundert
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -30,7 +30,7 @@ from .script import Script
 from .secrets import GeneratedSecret
 from difflib import get_close_matches
 from inform import (
-    Color, codicil, conjoin, cull, full_stop, is_collection, is_mapping, is_str,
+    codicil, conjoin, cull, full_stop, is_collection, is_mapping, is_str,
     join, log, notify, output, warn, indent, render
 )
 from textwrap import dedent
@@ -43,26 +43,18 @@ import re
 
 # Globals {{{1
 VECTOR_PATTERN = re.compile(r'\A(\w+)\[(\w+)\]\Z')
-LabelColor = Color(
-    color=get_setting('label_color'),
-    scheme=get_setting('color_scheme'),
-    enable=Color.isTTY()
-)
-HighlightColor = Color(
-    color=get_setting('highlight_color'),
-    scheme=get_setting('color_scheme'),
-    enable=Color.isTTY()
-)
 
 
 # Utilities {{{1
 def canonicalize(name):
-    return name.replace('-', '_').lower()
+    return name.replace('-', '_').replace(' ', '_').lower()
+
 
 def is_forbidden_field(name):
     # return true if a field name is intended only for internal use only
     return name.endswith('_') or name in FORBIDDEN_TOOL_FIELDS
 
+
 # AccountValue class {{{1
 class AccountValue:
     """An account value.
@@ -98,11 +90,11 @@ class AccountValue:
                 sequence.  The first one for which all keys are known is used.
                 The possible keys are:
 
-                | n -- name (identifier for the first level of a field)
-                | k -- key (identifier for the second level of a field)
-                | f -- field (name.key)
-                | d -- description
-                | v -- value
+                | n — name (identifier for the first level of a field)
+                | k — key (identifier for the second level of a field)
+                | f — field (name.key)
+                | d — description
+                | v — value
 
                 If none work, the value alone is returned.
         Returns:
@@ -389,10 +381,11 @@ class Account(object):
             fields = sorted(cls.__dict__)
         else:
             fields = cls.__dict__
+        hidden_fields = get_setting('hidden_fields').split() + HIDDEN_TOOL_FIELDS
         for field in fields:
             if field.startswith('_') or is_forbidden_field(field):
                 continue
-            if all or field not in HIDDEN_TOOL_FIELDS:
+            if all or field not in hidden_fields:
                 yield field
 
     # items() {{{2
@@ -617,12 +610,12 @@ class Account(object):
     def find_field(cls, name, key=None):
         # look up field name while ignoring case and treating - and _ as same
         names = {
-            n.replace('-', '_').lower(): n
+            canonicalize(n): n
             for n in cls.__dict__.keys()
             if not is_forbidden_field(n)
         }
         try:
-            name = names[name.replace('-', '_').lower()]
+            name = names[canonicalize(name)]
         except KeyError:
             raise PasswordError('field not found.', culprit=name)
 
@@ -636,11 +629,11 @@ class Account(object):
         try:
             value = getattr(cls, name)
             keys = {
-                n.replace('-', '_').lower(): n
+                canonicalize(n): n
                 for n in value.keys()
             }
             try:
-                key = keys[key.replace('-', '_').lower()]
+                key = keys[canonicalize(key)]
             except KeyError:
                 raise PasswordError('key not found.', culprit=key)
         except AttributeError:
@@ -787,6 +780,8 @@ class Account(object):
     @classmethod
     def write_summary(cls, all=False, sort=False):
         # present all account values that are not explicitly secret to the user
+        label_color = get_setting('_label_color')
+        highlight_color = get_setting('_highlight_color')
 
         def fmt_field(name, value='', key=None, level=0):
             hl = False
@@ -796,7 +791,7 @@ class Account(object):
                 hl = True
                 value = value.script
             elif cls.is_secret(name, key):
-                reveal = "reveal with: {}".format(HighlightColor(join(
+                reveal = "reveal with: {}".format(highlight_color(join(
                     'avendesora',
                     'value',
                     cls.get_name(),
@@ -818,11 +813,11 @@ class Account(object):
             else:
                 sep = ''
             if hl:
-                value = HighlightColor(value)
+                value = highlight_color(value)
             name = str(name).replace('_', ' ')
             leader = level * get_setting('indent')
             return indent(
-                LabelColor((name if key is None else str(key)) + ':') + sep + value,
+                label_color((name if key is None else str(key)) + ':') + sep + value,
                 leader
             )
 
@@ -870,11 +865,12 @@ class Account(object):
 
     # export() {{{2
     @classmethod
-    def export(cls):
+    def export(cls, fold_level=1):
         # return all account fields along with their values
         """Return all account fields along with their values as a dictionary
 
-        Used when exporting accounts.
+        Used when exporting accounts.  If fold_level is truthy, it should be a
+        positive integer that indicates the fold level for each account.
 
         Returns:
             A string that contains all account fields with all secrets included
@@ -886,10 +882,10 @@ class Account(object):
             if k not in ['master_seed', 'account_seed']
         ]
         return dedent('''
-            class {name}(Account): {fold}
+            class {name}(Account):{fold}
                 {values}
         ''').format(
-            fold = '# {{' + '{1',
+            fold = '  # {' + '{' + '{' + str(fold_level) if fold_level else '',
             name = cls.__name__,
             values = '\n    '.join(values),
         ).strip()
@@ -900,9 +896,10 @@ class Account(object):
         if not browser_name:
             browser_name = cls.get_scalar('browser', default=None)
         browser = StandardBrowser(browser_name)
+        label_color = get_setting('_label_color')
+        highlight_color = get_setting('_highlight_color')
 
         # get the urls from the urls attribute
-        # this must be second so it overrides those from recognizers.
         primary_urls = getattr(cls, 'urls', [])
         if type(primary_urls) != dict:
             if is_str(primary_urls):
@@ -924,16 +921,16 @@ class Account(object):
                 if is_collection(url):
                     url = list(Collection(url))[0]
                 if name == default:
-                    url += HighlightColor(' [default]')
+                    url += highlight_color(' [default]')
                     if not name:
                         name = ''
                 elif not name:
                     continue
-                output(LabelColor('{:>24s}:'.format(name)), url)
+                output(label_color('{:>24s}:'.format(name)), url)
             return
 
         # select the urls
-        keys = cull(list(urls.keys()))
+        keys = list(urls.keys())
         if not key:
             key = getattr(cls, 'default_url', None)
         if not key and keys and len(keys) == 1:
