@@ -1,7 +1,7 @@
 # Avendesora Password Generator Preferences
 
 # License {{{1
-# Copyright (C) 2016-2020 Kenneth S. Kundert
+# Copyright (C) 2016-2022 Kenneth S. Kundert
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
 
 # Imports {{{1
 from textwrap import dedent
-import re
 from appdirs import user_config_dir, user_cache_dir
 
 # Non-Config Settings {{{1
@@ -33,7 +32,8 @@ NONCONFIG_SETTINGS = {
     'default_stealth_accounts_file': 'stealth_accounts',
     'charsets_hash': 'a055240c4c498e1470f5f3e80b3ec599',
     'dict_hash': '5dbabd4114eae520c1de8963a8b8d09d',
-    'secrets_hash': 'f7a47122864464703212663a407e4cb6',
+    'mnemonic_hash': 'cafd522d6627011d78e576f2d0b6ed58',
+    'secrets_hash': '269d5bed6b564471b6581bf3309a6209',
     'discard_logfile': False,
     'commonly_mistaken_attributes': {
         'url': 'urls',
@@ -45,76 +45,80 @@ NONCONFIG_SETTINGS = {
 
 # Config Settings {{{1
 # These are the default values for settings that may be found in the config file
-CONFIG_DEFAULTS = {
-    'accounts_files': [
+CONFIG_DEFAULTS = dict(
+    accounts_files = [
         NONCONFIG_SETTINGS['default_accounts_file'],
         NONCONFIG_SETTINGS['default_stealth_accounts_file'],
     ],
-    'account_list_file': 'accounts_files',
-    'archive_file': 'archive.gpg',
-    'archive_stale': 1,
-    'previous_archive_file': 'archive.prev.gpg',
-    'config_dir_mask': 0o077,
-    'account_file_mask': 0o077,
-    'command_aliases': None,
-    'credential_ids': 'username email',
-    'credential_secrets': 'passcode password passphrase',
-    'label_color': 'blue',
-    'highlight_color': 'magenta',
-    'color_scheme': 'dark',
-    'browsers': {
-        'c':  'google-chrome {url}',
-        'ci': 'google-chrome --incognito {url}',
-        'f':  'firefox -new-tab {url}',
-        'fp':  'firefox -private-window {url}',
-        'q':  'qutebrowser {url}',
-        't':  'torbrowser {url}',
-        'x':  'xdg-open {url}', # system default browser
-    },
-    'help_url': 'https://avendesora.readthedocs.io/en/latest',
-    'default_field': 'passcode password passphrase',
-    'default_vector_field': 'questions',
-    'dynamic_fields': '',
-    'default_browser': 'x',
-    'display_time': 60,
-    'ms_per_char': None,
-    'dictionary_file': None,
-    'encoding': 'utf-8',
-    'edit_account': (
-        'gvim',                     # use gvim -v so that user can access
-        '-v',                       # the X clipboard buffers
+    account_list_file = 'accounts_files',
+    archive_file = 'archive.gpg',
+    archive_stale = 1,
+    previous_archive_file = 'archive.prev.gpg',
+    config_dir_mask = 0o077,
+    account_file_mask = 0o077,
+    command_aliases = None,
+    credential_ids = 'username email',
+    credential_secrets = 'passcode password passphrase',
+    label_color = 'blue',
+    highlight_color = 'magenta',
+    color_scheme = 'dark',
+    browsers = dict(
+        c =  'google-chrome {url}',
+        ci = 'google-chrome --incognito {url}',
+        f =  'firefox -new-tab {url}',
+        fp =  'firefox -private-window {url}',
+        q =  'qutebrowser {url}',
+        t =  'torbrowser {url}',
+        x =  'xdg-open {url}',  # system default browser
+    ),
+    help_url = 'https://avendesora.readthedocs.io/en/latest',
+    default_field = 'passcode password passphrase',
+    default_vector_field = 'questions',
+    dynamic_fields = '',
+    hidden_fields = '',
+    default_browser = 'x',
+    display_time = 60,
+    ms_per_char = None,
+    dictionary_file = None,
+    encoding = 'utf-8',
+    edit_account = (
+        'gvim',                       # use gvim -v so that user can access
+        '-v',                         # the X clipboard buffers
         '+silent! /^class {account}(Account):/',
-        '+silent! normal zozt',     # open the fold, position near top of screen
+        '+silent! normal zozt',       # open the fold, position near top of screen
         '{filepath}'
     ),
-    'edit_template': (
-        'gvim',                     # use gvim -v so that user can access
-        '-v',                       # the X clipboard buffers
-        r'+silent! /_[A-Z0-9_]\+_/',# matches user modifiable template fields
-                                    # fields take the form '_AAA_'
-        '+silent! normal zozt',     # open the fold, position near top of screen
+    edit_template = (
+        'gvim',                       # use gvim -v so that user can access
+        '-v',                         # the X clipboard buffers
+        r'+silent! /_[A-Z0-9_]\+_/',  # matches user modifiable template fields
+                                      # fields take the form '_AAA_'
+        '+silent! normal zozt',       # open the fold, position near top of screen
         '{filepath}'
     ),
-    'hashes_file': 'hashes',
-    'indent': '    ',
-    'log_file': 'log.gpg',
-    'default_protocol': 'https',
-    'user_key_file': 'key.gpg',
-    'use_pager': True,
-    'selection_utility': 'gtk',
-    'verbose': False,
-    'default_account_template': 'bank',
-    'account_templates': {
-        'website': dedent("""
+    hashes_file = 'hashes',
+    indent = '    ',
+    log_file = 'log.gpg',
+    default_protocol = 'https',
+    user_key_file = 'key.gpg',
+    use_pager = True,
+    selection_utility = 'gtk',
+    verbose = False,
+    default_account_template = 'bank',
+    account_templates = dict(
+        website = dedent("""
             class _NAME_(Account): # %s1
                 desc = '_DESCRIPTION_'
                 aliases = '_ALIAS1_ _ALIAS2_'
                 username = '_USERNAME_'
                 email = '_EMAIL_'
-                passcode = PasswordRecipe('12 2u 2d 2s')
-            # Avendesora: length is 12, includes 2 upper, 2 digits and 2 symbols
-            # Avendesora: Alternatively use '12 2u 2d 2c!@#$&' to specify valid symbol characters.
-            # Avendesora: Alternatively use Passphrase()
+                passcode = Password()
+            # Avendesora: above provides a random selection of letters and digits
+            # Avendesora: Alternative 1: passcode = PasswordRecipe('12 2u 2d 2s')
+            # Avendesora:     length is 12, includes 2 upper, 2 digits and 2 symbols
+            # Avendesora:     use '12 2u 2d 2c!@#$&' to specify valid symbol characters.
+            # Avendesora: Alternative 2: passcode = Passphrase()
+            # Avendesora:     provides a random selection of 4 words
                 questions = [
                     Question("_QUESTION1_?"),
                     Question("_QUESTION2_?"),
@@ -137,7 +141,7 @@ CONFIG_DEFAULTS = {
             # Avendesora: Fields surrounded by << and >> will be hidden.
             # Avendesora: All lines that begin with '# Avendesora:' are automatically removed.
         """ % (3*'{')),
-        'shell': dedent("""
+        shell = dedent("""
             class _NAME_(Account): # %s1
                 desc = '_DESCRIPTION_'
                 aliases = '_ALIAS1_ _ALIAS2_'
@@ -156,17 +160,17 @@ CONFIG_DEFAULTS = {
             # Avendesora: Fields surrounded by << and >> will be hidden.
             # Avendesora: All lines that begin with '# Avendesora:' are deleted.
         """ % (3*'{')),
-        'bank': dedent("""
+        bank = dedent("""
             class _NAME_(Account): # %s1
                 desc = '_DESCRIPTION_'
                 aliases = '_ALIAS1_ _ALIAS2_'
                 username = '_NAME_'
                 email = '_EMAIL_'
-                accounts = {
-                    'checking':   <<_ACCOUNT_NUMBER_>>,
-                    'savings':    <<_ACCOUNT_NUMBER_>>,
-                    'creditcard': <<_ACCOUNT_NUMBER_>>,
-                }
+                accounts = dict(
+                    checking =   <<_ACCOUNT_NUMBER_>>,
+                    savings =    <<_ACCOUNT_NUMBER_>>,
+                    creditcard = <<_ACCOUNT_NUMBER_>>,
+                )
                 customer_service = '_PHONE_NUMBER_'
                 passcode = PasswordRecipe('12 2u 2d 2s')
             # Avendesora: length is 12, includes 2 upper, 2 digits and 2 symbols
@@ -195,19 +199,22 @@ CONFIG_DEFAULTS = {
             # Avendesora: Fields surrounded by << and >> will be hidden.
             # Avendesora: All lines that begin with '# Avendesora:' are deleted.
         """ % (3*'{')),
-    },
+    ),
+    additional_account_templates = {},
+        # should be empty dictionary
+        # the user is expected to set this value, which will be added to account templates
 
     # use absolute paths for executables so they cannot be maliciously replaced
     # by changing the path.
-    'gpg_executable': '/usr/bin/gpg2',
-    'gpg_home': '~/.gnupg',
-    'gpg_armor': 'extension',
-    'gpg_ids': None,
-    'xdotool_executable': '/usr/bin/xdotool',
-    'xsel_executable': '/usr/bin/xsel',
-    'dmenu_executable': '/usr/bin/dmenu',
-    'arp_executable': '/sbin/arp',
-}
+    gpg_executable = '/usr/bin/gpg2',
+    gpg_home = '~/.gnupg',
+    gpg_armor = 'extension',
+    gpg_ids = None,
+    xdotool_executable = '/usr/bin/xdotool',
+    xsel_executable = '/usr/bin/xsel',
+    dmenu_executable = '/usr/bin/dmenu',
+    arp_executable = '/sbin/arp',
+)
 
 # The following could be config settings, but they do not seem worth promoting.
 INITIAL_AUTOTYPE_DELAY = 0.25
@@ -241,6 +248,8 @@ CONFIG_FILE_INITIAL_CONTENTS = dedent('''\
         A = 'archive',
         b = 'browse',
         bc = 'browse --browser c',
+        bf = ["browse", "--browser", "f"],
+        bq = ["browse", "--browser", "q"],
         c = 'conceal',
         C = 'changed',
         e = 'edit',
@@ -260,6 +269,8 @@ CONFIG_FILE_INITIAL_CONTENTS = dedent('''\
         qc = 'questions --clipboard',
         r = 'reveal',
         s = 'search',
+        sum = "values",
+        summary = "values",
         val = 'value',
         v = 'value',
         vc = 'value --clipboard',
@@ -299,7 +310,8 @@ CONFIG_DOC_FILE_INITIAL_CONTENTS = dedent('''\
 
     archive_stale = {archive_stale}
         # The archive file is consider stale if it is this many days older than
-        # the most recently updated account file.
+        # the most recently updated account file, in which case a warning is
+        # given.  Set this to 0 to disable the warning.
 
     default_field = {default_field}
         # The name of the field to use for the value command when one is not
@@ -318,6 +330,11 @@ CONFIG_DOC_FILE_INITIAL_CONTENTS = dedent('''\
         # mentioned by the *changed* command, even if their value differs from
         # when the last archive was created.
 
+    hidden_fields = {hidden_fields}
+        # Names of fields that should not appear in the summary produced by the
+        # values command unless the --all option is specified.  A typical value
+        # includes estimated_value, postmortem_recipients, and bitwarden.
+
     credential_ids = {credential_ids}
         # A string that contains the field names (space separated) that should be
         # considered by the credentials command for the account identity.
@@ -447,6 +464,9 @@ CONFIG_DOC_FILE_INITIAL_CONTENTS = dedent('''\
     # comments that can contain instructions to the user. They will are removed
     # when the account is created.
     account_templates = {account_templates}
+        # Setting this overrides the Avendesora supplied templates.
+    additional_account_templates = {additional_account_templates}
+        # Settine this adds to the Avendesora supplied templates.
     default_account_template = {default_account_template}
 
     # GPG settings
@@ -504,9 +524,18 @@ HASH_FILE_INITIAL_CONTENTS = dedent('''\
     # 5. If there are changes, do not upgrade and report the situation to
     #    Avendesora's authors.
 
-    charsets_hash = {charsets_hash}  # DO NOT CHANGE THIS LINE
-    dict_hash     = {dict_hash}  # DO NOT CHANGE THIS LINE
-    secrets_hash  = {secrets_hash}  # DO NOT CHANGE THIS LINE
+    charsets_hash = {charsets_hash}
+    dict_hash     = {dict_hash}
+    mnemonic_hash = {mnemonic_hash}
+    secrets_hash  = {secrets_hash}
+
+    # CHANGE THESE VALUES ONLY WHEN REQUESTED BY AVENDESORA AND IF YOU HAVE
+    # FOLLOWED THE ABOVE PROCEDURE TO ASSURE YOUR GENERATED SECRETS HAVE NOT
+    # CHANGED.
+
+    # Generally the best way to upgrade this file is to simply delete it and
+    # then run 'avendesora init', which will regenerate it with the updated
+    # values.
 ''')
 
 
@@ -554,7 +583,7 @@ ACCOUNTS_FILE_INITIAL_CONTENTS = dedent('''\
     try:
         import Scrypt
     except ImportError:
-        # You need to install scrypt using 'pip install scrypt' to use Scrypt
+        # You need to install scrypt using ‘pip install scrypt’ to use Scrypt
         pass
 
     # Shared Values {section}
@@ -562,10 +591,10 @@ ACCOUNTS_FILE_INITIAL_CONTENTS = dedent('''\
     #
     # Never disclose the master seed to anyone you are not collaborating with.
     # Never give it to your collaborator using an insecure channel, such as
-    # email.  If you have encrypted this file with your colloborator's public
+    # email.  If you have encrypted this file with your collaborator’s public
     # GPG key, is best to simply send the encrypted file to your
     # collaborator the first time. After than, you can send the account
-    # informaiton in clear text as long as you are careful not to expose the
+    # information in clear text as long as you are careful not to expose the
     # master_seed.
     master_seed = Hidden({master_seed}, secure=True)
     gpg_ids = {gpg_ids}
@@ -912,7 +941,5 @@ ACCOUNT_LIST_FILE_CONTENTS = dedent('''\
 # Fields {{{1
 # Fields reserved for use by Avendesora
 # They are not displayed by the values command.
-TOOL_FIELDS = '''
-    NAME aliases default discovery browser default_url
-    master_seed account_seed
-'''.split()
+HIDDEN_TOOL_FIELDS = 'NAME aliases default discovery browser default_url'.split()
+FORBIDDEN_TOOL_FIELDS = 'master_seed account_seed'.split()
