@@ -5,7 +5,7 @@
 # username, current directory, etc.)
 
 # License {{{1
-# Copyright (C) 2016-2020 Kenneth S. Kundert
+# Copyright (C) 2016-2022 Kenneth S. Kundert
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,8 +25,8 @@ from .collection import Collection
 from .config import get_setting
 from .error import PasswordError
 from .shlib import to_path, Run
-from .utilities import gethostname, getusername, OSErrors
-from inform import Error, cull, log, notify, warn, os_error, indent, render
+from .utilities import gethostname, getusername
+from inform import Error, cull, log, notify, warn, os_error, render
 from fnmatch import fnmatch
 try:
     from urllib.parse import urlparse
@@ -45,6 +45,7 @@ def render_arg(value, name=None):
         return name + '=' + rendered_value
     return rendered_value
 
+
 # Recognizer Base Class {{{1
 class Recognizer(object):
     def all_urls(self, components=False):
@@ -87,6 +88,7 @@ class Recognizer(object):
     def render(self):
         return render(self)
 
+
 # RecognizeAll {{{1
 class RecognizeAll(Recognizer):
     """Run script if all recognizers match.
@@ -612,7 +614,6 @@ class RecognizeEnvVar(Recognizer):
         if verbose:
             log('    %s: no match.' % self.get_name())
 
-
     def _inform_get_args(self):
         return []
 
@@ -756,7 +757,7 @@ class RecognizeFile(Recognizer):
                 return
         except FileNotFoundError:
             pass
-        except OSErrors as e:
+        except OSError as e:
             warn(os_error(e))
         if verbose:
             log('    %s: no match.' % self.get_name())
