@@ -32,7 +32,7 @@ doctests::
 
 
 # License {{{1
-# Copyright (C) 2016-2020 Kenneth S. Kundert
+# Copyright (C) 2016-2022 Kenneth S. Kundert
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -54,10 +54,10 @@ from .charsets import (
 )
 from .config import get_setting
 from .error import PasswordError
-from .dictionary import DICTIONARY
+from .dictionary import Dictionary
 from .obscure import ObscuredSecret
 from .utilities import error_source
-from inform import cull, log, output, terminate, warn, is_str
+from inform import conjoin, cull, log, output, terminate, warn, is_str
 import math
 import hashlib
 import getpass
@@ -130,7 +130,7 @@ class GeneratedSecret(object):
         account_seed = account.get_seed()
         if self.master is None:
             master_seed = account.get_scalar('master_seed', default=None)
-            master_source = account.get_scalar('_master_source', default=None)
+            master_source = account.get_scalar('_master_source_', default=None)
         else:
             master_seed = self.master
             master_source = 'secret'
@@ -140,9 +140,7 @@ class GeneratedSecret(object):
         if not master_seed:
             try:
                 try:
-                    master_seed = getpass.getpass(
-                        'master seed for %s: ' % account_name
-                    )
+                    master_seed = getpass.getpass('master seed: ')
                     master_source = 'user'
                 except EOFError:
                     output()
@@ -168,9 +166,7 @@ class GeneratedSecret(object):
         interactive_seed = ''
         if request_seed is True:
             try:
-                interactive_seed = getpass.getpass(
-                    'seed for %s: ' % account_name
-                )
+                interactive_seed = getpass.getpass('seed: ')
             except (EOFError, KeyboardInterrupt):
                 terminate()
         elif callable(request_seed):
@@ -426,6 +422,7 @@ class Password(GeneratedSecret):
 
     def __init__(self,
         length = 12,
+        *,
         alphabet = DISTINGUISHABLE,
         master = None,
         version = None,
@@ -459,9 +456,9 @@ class Password(GeneratedSecret):
 
         join = shift_sort_join if self.shift_sort else simple_join
         secret = self.secret = (
-            self.prefix
-          + join(self._symbols(self.alphabet, self.length), self.sep)
-          + self.suffix
+            self.prefix +
+            join(self._symbols(self.alphabet, self.length), self.sep) +
+            self.suffix
         )
         return secret
 
@@ -478,9 +475,16 @@ class Passphrase(Password):
         length (int):
             The number of items to draw from the alphabet when creating the
             password.
-        alphabet (collection of symbols):
-            The reservoir of legal symbols to use when creating the password.
-            By default this is a list of 10,000 words.
+        dictionary (str, [str], or callable):
+            The reservoir of legal symbols to use when creating the
+            password. If not given, or if 'default' is given, this is a
+            predefined list of 10,000 words. If given as 'bip39' or
+            'mnemonic', this is a predefined list of the 2048 bitcoin BIP-39
+            seed words.  Any other string is treated as a path to a file
+            that would contain the words. A list is taken as is. Finally,
+            you can pass a function that returns the list of words, in which
+            case the calling of the function is deferred until the words are
+            needed, which is helpful if creating the list is slow.
         master (str):
             Overrides the master seed that is used when generating the password.
             Generally, there is one master seed shared by all accounts contained
@@ -515,7 +519,8 @@ class Passphrase(Password):
 
     def __init__(self,
         length = 4,
-        alphabet = None,
+        *,
+        dictionary = None,
         master = None,
         version = None,
         sep = ' ',
@@ -529,7 +534,10 @@ class Passphrase(Password):
             raise PasswordError(
                 'expecting an integer for length.', culprit=error_source()
             )
-        self.alphabet = alphabet if alphabet else DICTIONARY.get_words
+        if not dictionary or is_str(dictionary):
+            self.alphabet = Dictionary(dictionary).get_words
+        else:
+            self.alphabet = dictionary
         self.master = master
         self.version = version
         self.shift_sort = False
@@ -587,6 +595,7 @@ class PIN(Password):
     """
     def __init__(self,
         length = 4,
+        *,
         alphabet = DIGITS,
         master = None,
         version = None,
@@ -623,8 +632,16 @@ class Question(Passphrase):
         length (int):
             The number of items to draw from the alphabet when creating the
             answer.
-        alphabet (collection of symbols):
-            The reservoir of legal symbols to use when creating the password.
+        dictionary (str, [str], or callable):
+            The reservoir of legal symbols to use when creating the
+            password. If not given, or if 'default' is given, this is a
+            predefined list of 10,000 words. If given as 'bip39' or
+            'mnemonic', this is a predefined list of the 2048 bitcoin BIP-39
+            seed words.  Any other string is treated as a path to a file
+            that would contain the words. A list is taken as is. Finally,
+            you can pass a function that returns the list of words, in which
+            case the calling of the function is deferred until the words are
+            needed, which is helpful if creating the list is slow.
         master (str):
             Overrides the master seed that is used when generating the password.
             Generally, there is one master seed shared by all accounts contained
@@ -673,13 +690,14 @@ class Question(Passphrase):
     def __init__(self,
         question,
         length = 3,
-        alphabet = None,
+        *,
+        answer = None,
+        dictionary = None,
         master = None,
         version = None,
         sep = ' ',
         prefix = '',
         suffix = '',
-        answer = None,
         is_secret = True,
     ):
         self.question = question
@@ -689,7 +707,10 @@ class Question(Passphrase):
             raise PasswordError(
                 'expecting an integer for length.', culprit=error_source()
             )
-        self.alphabet = alphabet if alphabet else DICTIONARY.get_words
+        if not dictionary or is_str(dictionary):
+            self.alphabet = Dictionary(dictionary).get_words
+        else:
+            self.alphabet = dictionary
         self.master = master
         self.version = version
         self.shift_sort = False
@@ -772,6 +793,7 @@ class MixedPassword(GeneratedSecret):
         length,
         def_alphabet,
         requirements,
+        *,
         master = None,
         version = None,
         shift_sort = False,
@@ -893,6 +915,7 @@ class PasswordRecipe(MixedPassword):
     def __init__(
         self,
         recipe,
+        *,
         def_alphabet = ALPHANUMERIC,
         master = None,
         version = None,
@@ -917,8 +940,8 @@ class PasswordRecipe(MixedPassword):
                 requirements += [(alphabet, int('0' + num))]
         except (ValueError, AttributeError):
             raise PasswordError(
-                each, recipe,
-                template="{0}: invalid term in recipe '{1}'.",
+                each, recipe, conjoin(self.ALPHABETS.keys(), conj=' or '),
+                template="{0}: invalid term in recipe '{1}'. Choose from {2}.",
                 culprit=error_source()
             )
 
@@ -990,6 +1013,7 @@ class BirthDate(GeneratedSecret):
         min_age = 18,
         max_age = 65,
         fmt = 'YYYY-MM-DD',
+        *,
         master = None,
         version = None,
         is_secret = True,
