@@ -4,7 +4,7 @@
 # shell-script-like things relatively easily in Python.
 
 # License {{{1
-# Copyright (C) 2016-2020 Kenneth S. Kundert
+# Copyright (C) 2016-2022 Kenneth S. Kundert
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,8 +19,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 
-__version__ = "1.2.1"
-__released__ = "2020-02-22"
+__version__ = "1.4.0"
+__released__ = "2021-11-10"
 
 # Imports {{{1
 try:
@@ -133,7 +133,7 @@ def _use_log(log):
 
 # Preferences {{{1
 def set_prefs(**kwargs):
-    """Set ShLib preferences
+    """Set shlib preferences
 
     Args:
         use_inform (bool):
@@ -212,7 +212,8 @@ def mv(*paths):
             shutil.move(to_str(src), to_str(dest))
     else:
         # destination does not exist
-        assert not dest.exists()
+        if dest.exists():
+            raise_os_error(errno.EEXIST, dest)
         shutil.move(to_str(src), to_str(dest))
 
 
@@ -221,7 +222,7 @@ def rm(*paths):
     "Remove files or directories (equivalent to rm -rf)"
     for path in to_paths(paths):
         try:
-            if path.is_dir():
+            if path.is_dir() and not path.is_symlink():
                 shutil.rmtree(to_str(path))
             else:
                 path.unlink()
@@ -275,9 +276,10 @@ class mount:
     def __init__(self, path):
         self.path = to_path(path)
         self.mounted_externally = is_mounted(self.path)
+        modes = 'sOEW0' if PREFERENCES["use_inform"] else 'soeW0'
 
         if not self.mounted_externally:
-            Run(["mount", self.path])
+            Run(["mount", self.path], modes=modes)
 
     def __enter__(self):
         pass
@@ -288,11 +290,13 @@ class mount:
 
 
 def umount(path):
-    Run(["umount", path])
+    modes = 'sOEW0' if PREFERENCES["use_inform"] else 'soeW0'
+    Run(["umount", path], modes=modes)
 
 
 def is_mounted(path):
-    return Run(["mountpoint", "-q", path], "0,1").status == 0
+    modes = 'sOEW1' if PREFERENCES["use_inform"] else 'soeW1'
+    return Run(["mountpoint", "-q", path], modes=modes).status == 0
 
 
 # cd {{{2
@@ -508,17 +512,13 @@ def cartesian_product(*fragments):
 
 
 # brace_expand()  {{{2
-try:
+
+def brace_expand(pattern):
+    """Bash-style brace expansion"""
     from braceexpand import braceexpand
 
-    def brace_expand(pattern):
-        """Bash-style brace expansion"""
-        for path in braceexpand(pattern):
-            yield to_path(path)
-
-
-except ImportError:
-    pass
+    for path in braceexpand(pattern):
+        yield to_path(path)
 
 
 # Execution classes and functions (Cmd, Run, Sh, Start, run, bg, shbg, which) {{{1
@@ -654,6 +654,7 @@ class Cmd(object):
                 )
             else:
                 raise
+        self.running = True
 
         # store needed information and wait for termination if desired
         self.pid = process.pid
@@ -710,6 +711,7 @@ class Cmd(object):
                 )
             else:
                 raise
+        self.running = True
 
         # store needed information and wait for termination if desired
         self.pid = process.pid
@@ -736,6 +738,7 @@ class Cmd(object):
         self.stdout = None if stdout is None else stdout.decode(self.encoding)
         self.stderr = None if stderr is None else stderr.decode(self.encoding)
         self.status = process.returncode
+        self.running = False
 
         if _use_log(self.log):
             from inform import log
@@ -763,10 +766,38 @@ class Cmd(object):
                 raise OSError(None, msg)
         return self.status
 
+    # poll {{{3
+    def poll(self):
+        """
+        Check to see if process has completed.
+
+        Returns exit status if process is done, otherwise it return None.
+        """
+        status = self.process.poll()
+        if status is None:
+            # still running
+            return
+        if self.running:
+            process = self.process
+            stdout, stderr = process.communicate()
+            self.stdout = None if stdout is None else stdout.decode(self.encoding)
+            self.stderr = None if stderr is None else stderr.decode(self.encoding)
+            assert status == process.returncode
+            self.status = status
+            self.running = False
+        return status
+
     # kill {{{3
     def kill(self):
-        self.process.kill()
-        self.process.wait()
+        """
+        Kill the process.
+        """
+        try:
+            self.process.kill()
+            self.process.wait()
+        except AttributeError:
+            # did not get far enough to set self.process
+            pass
 
     # __str__ {{{3
     def __str__(self):
@@ -1014,12 +1045,12 @@ def render_command(cmd, option_args=None, width=70):
     bux --dux a b -d c d --tux e f g h
 
     >>> print(render_command('bux --dux a b -d c d --tux e f g h', args, width=0))
-    bux \
-        --dux a b \
-        -d c d \
-        --tux e \
-        f \
-        g \
+    bux \\
+        --dux a b \\
+        -d c d \\
+        --tux e \\
+        f \\
+        g \\
         h
 
     """
